@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the account tab in https://developers.themoviedb.org/3/account
 '''
 
-def details(session_id):
+def details(session_id, disable_cache=False):
     '''
     Get your account details.
 
@@ -12,9 +12,9 @@ def details(session_id):
     optional:
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account?session_id={session_id}')
+    return _call('GET', f'https://api.themoviedb.org/3/account?session_id={session_id}', disable_cache)
 
-def created_lists(account_id, **kwargs):
+def created_lists(account_id, disable_cache=False, **kwargs):
     '''
     Get all of the lists created by an account. Will include private lists if you are the owner.
 
@@ -22,9 +22,9 @@ def created_lists(account_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/lists', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/lists', disable_cache, params=kwargs)
 
-def favorite_movies(account_id, **kwargs):
+def favorite_movies(account_id, disable_cache=False, **kwargs):
     '''
     Get the list of your favorite movies.
 
@@ -32,9 +32,9 @@ def favorite_movies(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/favorite/movies', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/favorite/movies', disable_cache, params=kwargs)
 
-def favorite_tv_shows(account_id, **kwargs):
+def favorite_tv_shows(account_id, disable_cache=False, **kwargs):
     '''
     Get the list of your favorite TV shows.
 
@@ -42,7 +42,7 @@ def favorite_tv_shows(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/favorite/tv', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/favorite/tv', disable_cache, params=kwargs)
 
 def mark_as_favorite(account_id, session_id, media_type, media_id, favorite):
     '''
@@ -54,9 +54,9 @@ def mark_as_favorite(account_id, session_id, media_type, media_id, favorite):
 
     payload = "{\"media_type\": \""+media_type+"\", \"media_id\": \""+str(media_id)+"\", \"favorite\": \""+str(favorite)+"\"}"
 
-    return _call('POST', f'https://api.themoviedb.org/3/account/{account_id}/favorite?session_id={session_id}', payload=payload)
+    return _call('POST', f'https://api.themoviedb.org/3/account/{account_id}/favorite?session_id={session_id}', True, payload=payload)
 
-def rated_movies(account_id, **kwargs):
+def rated_movies(account_id, disable_cache=False, **kwargs):
     '''
     Get a list of all the movies you have rated.
 
@@ -64,9 +64,9 @@ def rated_movies(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/movies', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/movies', disable_cache, params=kwargs)
 
-def rated_tv(account_id, **kwargs):
+def rated_tv(account_id, disable_cache=False, **kwargs):
     '''
     Get a list of all the TV shows you have rated.
 
@@ -74,9 +74,9 @@ def rated_tv(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/tv', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/tv', disable_cache, params=kwargs)
 
-def rated_tv_episodes(account_id, **kwargs):
+def rated_tv_episodes(account_id, disable_cache=False, **kwargs):
     '''
     Get a list of all the TV episodes you have rated.
 
@@ -84,9 +84,9 @@ def rated_tv_episodes(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/tv/episodes', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/rated/tv/episodes', disable_cache, params=kwargs)
 
-def movie_watchlist(account_id, **kwargs):
+def movie_watchlist(account_id, disable_cache=False, **kwargs):
     '''
     Get a list of all the movies you have added to your watchlist.
 
@@ -94,9 +94,9 @@ def movie_watchlist(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/watchlist/movies', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/watchlist/movies', disable_cache, params=kwargs)
 
-def tv_show_watchlist(account_id, **kwargs):
+def tv_show_watchlist(account_id, disable_cache=False, **kwargs):
     '''
     Get a list of all the TV shows you have added to your watchlist.
 
@@ -104,7 +104,7 @@ def tv_show_watchlist(account_id, **kwargs):
     optional: page, language, sort_by
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/watchlist/tv', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/account/{account_id}/watchlist/tv', disable_cache, params=kwargs)
 
 def add_to_watchlist(account_id, session_id, media_type, media_id, watchlist):
     '''
@@ -116,4 +116,4 @@ def add_to_watchlist(account_id, session_id, media_type, media_id, watchlist):
 
     payload = "{\"media_type\": \""+media_type+"\", \"media_id\": \""+str(media_id)+"\", \"watchlist\": \""+str(watchlist)+"\"}"
 
-    return _call('POST', f'https://api.themoviedb.org/3/account/{account_id}/watchlist?session_id={session_id}', payload=payload)
\ No newline at end of file
+    return _call('POST', f'https://api.themoviedb.org/3/account/{account_id}/watchlist?session_id={session_id}', True, payload=payload)
\ No newline at end of file
