@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the cerifications tab in https://developers.themoviedb.org/3/cerifications
 '''
 
-def movie():
+def movie(disable_cache=False):
     '''
     Get an up to date list of the officially supported movie certifications on TMDb.
 
@@ -12,9 +12,9 @@ def movie():
     optional:
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/certification/movie/list')
+    return _call('GET', f'https://api.themoviedb.org/3/certification/movie/list', disable_cache)
 
-def tv():
+def tv(disable_cache=False):
     '''
     Get an up to date list of the officially supported TV show certifications on TMDb.
 
@@ -22,4 +22,4 @@ def tv():
     optional:
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/certification/tv/list')
+    return _call('GET', f'https://api.themoviedb.org/3/certification/tv/list', disable_cache)
