@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the changes tab in https://developers.themoviedb.org/3/changes
 '''
 
-def movie(**kwargs):
+def movie(disable_cache=False, **kwargs):
     '''
     Get a list of all of the movie ids that have been changed in the past 24 hours.
     You can query it for up to 14 days worth of changed IDs at a time with the start_date and end_date query parameters.
@@ -14,9 +14,9 @@ def movie(**kwargs):
     optional: page, start_date, end_date
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/changes', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/changes', disable_cache, params=kwargs)
 
-def tv(**kwargs):
+def tv(disable_cache=False, **kwargs):
     '''
     Get a list of all of the TV show ids that have been changed in the past 24 hours.
     You can query it for up to 14 days worth of changed IDs at a time with the start_date and end_date query parameters.
@@ -26,9 +26,9 @@ def tv(**kwargs):
     optional: page, start_date, end_date
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/changes', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/changes', disable_cache, params=kwargs)
 
-def person(**kwargs):
+def person(disable_cache=False, **kwargs):
     '''
     Get a list of all of the person ids that have been changed in the past 24 hours.
     You can query it for up to 14 days worth of changed IDs at a time with the start_date and end_date query parameters.
@@ -38,4 +38,4 @@ def person(**kwargs):
     optional: page, start_date, end_date
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/person/changes', params=kwargs)
\ No newline at end of file
+    return _call('GET', f'https://api.themoviedb.org/3/person/changes', disable_cache, params=kwargs)
\ No newline at end of file
