@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the tv episode groups tab in https://developers.themoviedb.org/3/tv-episode-groups
 '''
 
-def details(group_id, **kwargs):
+def details(group_id, disable_cache=False, **kwargs):
     '''
     Get the details of a TV episode group. Groups support 7 different types which are enumerated as the following:
 
@@ -20,4 +20,4 @@ def details(group_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/episode_group/{group_id}', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/episode_group/{group_id}', disable_cache, params=kwargs)
