@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the genres tab in https://developers.themoviedb.org/3/genres
 '''
 
-def movie(**kwargs):
+def movie(disable_cache=False, **kwargs):
     '''
     Get the list of official genres for movies.
 
@@ -12,9 +12,9 @@ def movie(**kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/genre/movie/list', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/genre/movie/list', disable_cache, params=kwargs)
 
-def tv(**kwargs):
+def tv(disable_cache=False, **kwargs):
     '''
     Get the list of official genres for TV shows.
 
@@ -22,4 +22,4 @@ def tv(**kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/genre/tv/list', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/genre/tv/list', disable_cache, params=kwargs)
