@@ -5,7 +5,7 @@ All api requests under the movies tab in https://developers.themoviedb.org/3/mov
 '''
 
 
-def details(movie_id, **kwargs):
+def details(movie_id, disable_cache=False, **kwargs):
     '''
     Get the primary information about a movie.
     Supports append_to_response. https://developers.themoviedb.org/3/getting-started/append-to-response
@@ -14,10 +14,10 @@ def details(movie_id, **kwargs):
     optional: language, append_to_response
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}', disable_cache, params=kwargs)
 
 
-def account_states(movie_id, **kwargs):
+def account_states(movie_id, disable_cache=False, **kwargs):
     '''
     Grab the following account states for a session:
         Movie rating
@@ -28,10 +28,10 @@ def account_states(movie_id, **kwargs):
     optional:
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/account_states', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/account_states', disable_cache, params=kwargs)
 
 
-def alternative_titles(movie_id, **kwargs):
+def alternative_titles(movie_id, disable_cache=False, **kwargs):
     '''
     Get all of the alternative titles for a movie.
 
@@ -39,10 +39,10 @@ def alternative_titles(movie_id, **kwargs):
     optional: country
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/alternative_titles', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/alternative_titles', disable_cache, params=kwargs)
 
 
-def changes(movie_id, **kwargs):
+def changes(movie_id, disable_cache=False, **kwargs):
     '''
     Get the changes for a movie. By default only the last 24 hours are returned.
     You can query up to 14 days in a single query by using the start_date and end_date query parameters.
@@ -51,10 +51,10 @@ def changes(movie_id, **kwargs):
     optional: page, start_date, end_date
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/changes', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/changes', disable_cache, params=kwargs)
 
 
-def credits(movie_id):
+def credits(movie_id, disable_cache=False):
     '''
     Get the cast and crew for a movie.
 
@@ -62,10 +62,10 @@ def credits(movie_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/credits')
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/credits', disable_cache)
 
 
-def external_ids(movie_id):
+def external_ids(movie_id, disable_cache=False):
     '''
     Get the external ids for a movie. We currently support the following external sources.
 
@@ -80,10 +80,10 @@ def external_ids(movie_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/external_ids')
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/external_ids', disable_cache)
 
 
-def images(movie_id, **kwargs):
+def images(movie_id, disable_cache=False, **kwargs):
     '''
     Get the images that belong to a movie.
     Querying images with a language parameter will filter the results.
@@ -94,10 +94,10 @@ def images(movie_id, **kwargs):
     optional: language, include_image_language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/images', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/images', disable_cache, params=kwargs)
 
 
-def keywords(movie_id):
+def keywords(movie_id, disable_cache=False):
     '''
     Get the keywords that have been added to a movie.
 
@@ -105,10 +105,10 @@ def keywords(movie_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/keywords')
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/keywords', disable_cache)
 
 
-def release_dates(movie_id):
+def release_dates(movie_id, disable_cache=False):
     '''
     Get the release date along with the certification for a movie.
     Release dates support different types:
@@ -123,10 +123,10 @@ def release_dates(movie_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/release_dates')
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/release_dates', disable_cache)
 
 
-def videos(movie_id, **kwargs):
+def videos(movie_id, disable_cache=False, **kwargs):
     '''
     Get the videos that have been added to a movie.
 
@@ -134,10 +134,10 @@ def videos(movie_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/videos', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/videos', disable_cache, params=kwargs)
 
 
-def translations(movie_id):
+def translations(movie_id, disable_cache=False):
     '''
     Get a list of translations that have been created for a movie.
 
@@ -145,10 +145,10 @@ def translations(movie_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/translations')
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/translations', disable_cache)
 
 
-def recommendations(movie_id, **kwargs):
+def recommendations(movie_id, disable_cache=False, **kwargs):
     '''
     Get a list of recommended movies for a movie.
 
@@ -156,10 +156,10 @@ def recommendations(movie_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/recommendations', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/recommendations', disable_cache, params=kwargs)
 
 
-def similar(movie_id, **kwargs):
+def similar(movie_id, disable_cache=False, **kwargs):
     '''
     Get a list of similar movies. This is not the same as the 'Recommendation' system you see on the website.
     These items are assembled by looking at keywords and genres.
@@ -168,10 +168,10 @@ def similar(movie_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/similar', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/similar', disable_cache, params=kwargs)
 
 
-def reviews(movie_id, **kwargs):
+def reviews(movie_id, disable_cache=False, **kwargs):
     '''
     Get the user reviews for a movie.
 
@@ -179,10 +179,10 @@ def reviews(movie_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/reviews', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/reviews', disable_cache, params=kwargs)
 
 
-def lists(movie_id, **kwargs):
+def lists(movie_id, disable_cache=False, **kwargs):
     '''
     Get a list of lists that this movie belongs to.
 
@@ -190,10 +190,10 @@ def lists(movie_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/lists', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/{movie_id}/lists', disable_cache, params=kwargs)
 
 
-def latest(**kwargs):
+def latest(disable_cache=False, **kwargs):
     '''
     Get the most newly created movie. This is a live response and will continuously change.
 
@@ -201,10 +201,10 @@ def latest(**kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/latest', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/latest', disable_cache, params=kwargs)
 
 
-def now_playing(**kwargs):
+def now_playing(disable_cache=False, **kwargs):
     '''
     Get a list of movies in theatres. This is a release type query that looks for all movies that have a release type of 2 or 3 within the specified date range.
     You can optionally specify a region prameter which will narrow the search to only look for theatrical release dates within the specified country.
@@ -213,10 +213,10 @@ def now_playing(**kwargs):
     optional: page, language, region
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/now_playing', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/now_playing', disable_cache, params=kwargs)
 
 
-def popular(**kwargs):
+def popular(disable_cache=False, **kwargs):
     '''
     Get a list of the current popular movies on TMDb. This list updates daily.
 
@@ -224,10 +224,10 @@ def popular(**kwargs):
     optional: page, language, region
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/popular', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/popular', disable_cache, params=kwargs)
 
 
-def top_rated(**kwargs):
+def top_rated(disable_cache=False, **kwargs):
     '''
     Get the top rated movies on TMDb.
 
@@ -235,10 +235,10 @@ def top_rated(**kwargs):
     optional: page, language, region
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/top_rated', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/top_rated', disable_cache, params=kwargs)
 
 
-def upcoming(**kwargs):
+def upcoming(disable_cache=False, **kwargs):
     '''
     Get a list of upcoming movies in theatres. This is a release type query that looks for all movies that have a release type of 2 or 3 within the specified date range.
     You can optionally specify a region prameter which will narrow the search to only look for theatrical release dates within the specified country.
@@ -247,7 +247,7 @@ def upcoming(**kwargs):
     optional: page, language, region
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/movie/upcoming', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/movie/upcoming', disable_cache, params=kwargs)
 
 
 def rate_movie(movie_id, rating, **kwargs):
@@ -261,7 +261,7 @@ def rate_movie(movie_id, rating, **kwargs):
 
     payload = "{\"value\": \""+str(rating)+"\"}"
 
-    return _call('POST', f'https://api.themoviedb.org/3/movie/{movie_id}/rating', params=kwargs, payload=payload)
+    return _call('POST', f'https://api.themoviedb.org/3/movie/{movie_id}/rating', True, params=kwargs, payload=payload)
 
 
 def delete_rating(movie_id, **kwargs):
@@ -273,4 +273,4 @@ def delete_rating(movie_id, **kwargs):
     optional: 
     '''
 
-    return _call('DELETE', f'https://api.themoviedb.org/3/movie/{movie_id}/rating', params=kwargs)
+    return _call('DELETE', f'https://api.themoviedb.org/3/movie/{movie_id}/rating', True, params=kwargs)
