@@ -4,7 +4,7 @@ from ..base import _call
 All api requests under the tv tab in https://developers.themoviedb.org/3/tv
 '''
 
-def details(tv_id, **kwargs):
+def details(tv_id, disable_cache=False, **kwargs):
     '''
     Get the primary TV show details by id.
     Supports append_to_response. https://developers.themoviedb.org/3/getting-started/append-to-response
@@ -13,9 +13,9 @@ def details(tv_id, **kwargs):
     optional: language, append_to_response
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}', disable_cache, params=kwargs)
 
-def account_states(tv_id, **kwargs):
+def account_states(tv_id, disable_cache=False, **kwargs):
     '''
     Grab the following account states for a session:
         TV show rating
@@ -26,9 +26,9 @@ def account_states(tv_id, **kwargs):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/account_states', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/account_states', disable_cache, params=kwargs)
 
-def alternative_titles(tv_id, **kwargs):
+def alternative_titles(tv_id, disable_cache=False, **kwargs):
     '''
     Returns all of the alternative titles for a TV show.
 
@@ -36,9 +36,9 @@ def alternative_titles(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/alternative_titles', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/alternative_titles', disable_cache, params=kwargs)
 
-def changes(tv_id, **kwargs):
+def changes(tv_id, disable_cache=False, **kwargs):
     '''
     Get the changes for a TV show. By default only the last 24 hours are returned.
     You can query up to 14 days in a single query by using the start_date and end_date query parameters.
@@ -51,9 +51,9 @@ def changes(tv_id, **kwargs):
     optional: page, start_date, end_date
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/changes', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/changes', disable_cache, params=kwargs)
 
-def content_ratings(tv_id, **kwargs):
+def content_ratings(tv_id, disable_cache=False, **kwargs):
     '''
     Get the list of content ratings (certifications) that have been added to a TV show.
 
@@ -61,9 +61,9 @@ def content_ratings(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/content_ratings', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/content_ratings', disable_cache, params=kwargs)
 
-def credits(tv_id, **kwargs):
+def credits(tv_id, disable_cache=False, **kwargs):
     '''
     Get the credits (cast and crew) that have been added to a TV show.
 
@@ -71,9 +71,9 @@ def credits(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/credits', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/credits', disable_cache, params=kwargs)
 
-def episode_groups(tv_id, **kwargs):
+def episode_groups(tv_id, disable_cache=False, **kwargs):
     '''
     Get all of the episode groups that have been created for a TV show.
     With a group ID you can call the https://developers.themoviedb.org/3/tv-episode-groups/get-tv-episode-group-details method.
@@ -82,9 +82,9 @@ def episode_groups(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/episode_groups', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/episode_groups', disable_cache, params=kwargs)
 
-def external_ids(tv_id, **kwargs):
+def external_ids(tv_id, disable_cache=False, **kwargs):
     '''
     Get the external ids for a TV show. We currently support the following external sources.
 
@@ -105,9 +105,9 @@ def external_ids(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/external_ids', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/external_ids', disable_cache, params=kwargs)
 
-def images(tv_id, **kwargs):
+def images(tv_id, disable_cache=False, **kwargs):
     '''
     Get the images that belong to a TV show.
     Querying images with a language parameter will filter the results.
@@ -118,9 +118,9 @@ def images(tv_id, **kwargs):
     optional: language, include_image_language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/images', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/images', disable_cache, params=kwargs)
 
-def keywords(tv_id):
+def keywords(tv_id, disable_cache=False):
     '''
     Get the keywords that have been added to a TV show.
 
@@ -128,9 +128,9 @@ def keywords(tv_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/keywords')
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/keywords', disable_cache)
 
-def recommendations(tv_id, **kwargs):
+def recommendations(tv_id, disable_cache=False, **kwargs):
     '''
     Get the list of TV show recommendations for this item.
 
@@ -138,9 +138,9 @@ def recommendations(tv_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/recommendations', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/recommendations', disable_cache, params=kwargs)
 
-def reviews(tv_id, **kwargs):
+def reviews(tv_id, disable_cache=False, **kwargs):
     '''
     Get the reviews for a TV show.
 
@@ -148,9 +148,9 @@ def reviews(tv_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/reviews', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/reviews', disable_cache, params=kwargs)
 
-def screened_theatrically(tv_id):
+def screened_theatrically(tv_id, disable_cache=False):
     '''
     Get a list of seasons or episodes that have been screened in a film festival or theatre.
 
@@ -158,9 +158,9 @@ def screened_theatrically(tv_id):
     optional: 
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/screened_theatrically')
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/screened_theatrically', disable_cache)
 
-def similar(tv_id, **kwargs):
+def similar(tv_id, disable_cache=False, **kwargs):
     '''
     Get a list of similar TV shows.
     These items are assembled by looking at keywords and genres.
@@ -169,9 +169,9 @@ def similar(tv_id, **kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/similar', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/similar', disable_cache, params=kwargs)
 
-def translations(tv_id, **kwargs):
+def translations(tv_id, disable_cache=False, **kwargs):
     '''
     Get a list of the translations that exist for a TV show.
 
@@ -179,9 +179,9 @@ def translations(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/translations', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/translations', disable_cache, params=kwargs)
 
-def videos(tv_id, **kwargs):
+def videos(tv_id, disable_cache=False, **kwargs):
     '''
     Get the videos that have been added to a TV show.
 
@@ -189,9 +189,9 @@ def videos(tv_id, **kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/videos', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/{tv_id}/videos', disable_cache, params=kwargs)
 
-def latest(**kwargs):
+def latest(disable_cache=False, **kwargs):
     '''
     Get the most newly created TV show. This is a live response and will continuously change.
 
@@ -199,9 +199,9 @@ def latest(**kwargs):
     optional: language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/latest', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/latest', disable_cache, params=kwargs)
 
-def airing_today(**kwargs):
+def airing_today(disable_cache=False, **kwargs):
     '''
     Get a list of TV shows that are airing today. This query is purely day based as we do not currently support airing times.
     You can specify a timezone to offset the day calculation. Without a specified timezone, this query defaults to EST (Eastern Time UTC-05:00).
@@ -210,9 +210,9 @@ def airing_today(**kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/airing_today', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/airing_today', disable_cache, params=kwargs)
 
-def on_the_air(**kwargs):
+def on_the_air(disable_cache=False, **kwargs):
     '''
     Get a list of shows that are currently on the air.
     This query looks for any TV show that has an episode with an air date in the next 7 days.
@@ -221,9 +221,9 @@ def on_the_air(**kwargs):
     optional: page, language, region
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/on_the_air', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/on_the_air', disable_cache, params=kwargs)
 
-def popular(**kwargs):
+def popular(disable_cache=False, **kwargs):
     '''
     Get a list of the current popular TV shows on TMDb. This list updates daily.
 
@@ -231,9 +231,9 @@ def popular(**kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/popular', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/popular', disable_cache, params=kwargs)
 
-def top_rated(**kwargs):
+def top_rated(disable_cache=False, **kwargs):
     '''
     Get a list of the top rated TV shows on TMDb.
 
@@ -241,7 +241,7 @@ def top_rated(**kwargs):
     optional: page, language
     '''
 
-    return _call('GET', f'https://api.themoviedb.org/3/tv/top_rated', params=kwargs)
+    return _call('GET', f'https://api.themoviedb.org/3/tv/top_rated', disable_cache, params=kwargs)
 
 def rate_movie(tv_id, rating, **kwargs):
     '''
@@ -254,7 +254,7 @@ def rate_movie(tv_id, rating, **kwargs):
 
     payload = "{\"value\": \""+str(rating)+"\"}"
 
-    return _call('POST', f'https://api.themoviedb.org/3/tv/{tv_id}/rating', params=kwargs, payload=payload)
+    return _call('POST', f'https://api.themoviedb.org/3/tv/{tv_id}/rating', True, params=kwargs, payload=payload)
 
 def delete_rating(tv_id, **kwargs):
     '''
@@ -265,4 +265,4 @@ def delete_rating(tv_id, **kwargs):
     optional: 
     '''
 
-    return _call('DELETE', f'https://api.themoviedb.org/3/tv/{tv_id}/rating', params=kwargs)
\ No newline at end of file
+    return _call('DELETE', f'https://api.themoviedb.org/3/tv/{tv_id}/rating', True, params=kwargs)
\ No newline at end of file
